* pics.do
version 11

clear all
set seed 12345
set obs 1000

gen y = 10*uniform()
gen x = 10*uniform()

gen uy = floor(y)
gen ux = floor(x)
egen unit = group(uy ux)
drop uy ux

gen sy = floor(y/5)
gen sx = floor(x/5)
egen stratum = group(sy sx)
drop sy sx

local N_pop = c(N)

gen double r1 = uniform()
gen double r2 = uniform()
sort r1 r2
gen sel_srs = _n <= _N*.2
count if sel_srs
local N_srs = r(N)

replace r1 = uniform()
replace r2 = uniform()
sort stratum r1 r2
by stratum : gen sel_str = _n < _N*.2
count if sel_str
local N_str = r(N)

sort unit
by unit : replace r1 = cond(_n==1, uniform(), .)
by unit : replace r2 = cond(_n==1, uniform(), .)
sort r1 r2
gen sel_psu = _n <= 20
count if sel_psu
local N_psu = r(N)
sort unit r1 r2
by unit : replace sel_psu = sel_psu[1]
count if sel_psu
local M_psu = r(N)

sort stratum unit
by stratum unit : replace r1 = cond(_n==1, uniform(), .)
by stratum unit : replace r2 = cond(_n==1, uniform(), .)
sort stratum r1 r2
by stratum : gen sel_scl = _n <= 5
count if sel_scl
local N_scl = r(N)
sort stratum unit r1 r2
by stratum unit : replace sel_scl = sel_scl[1]
count if sel_scl
local M_scl = r(N)

local twopts	yscale(off)		///
		ylabel(, nogrid)	///
		xscale(off)		///
		xlabel(, nogrid)	///
		graphregion(		///
			style(none)	///
		)			///
		plotregion(		///
			margin(zero)	///
		)			///
		legend(off)		///
					 // blank

local ttl title("Population `N_pop'")
graph twoway	(scatter y x, mcolor(blue))			///
		, `twopts'					///
		`ttl'						///
		name(pop)
graph export ../tex/pics/pic_pop.pdf, replace

local ttl title("SRS sample `N_srs'")
graph twoway	(scatter y x if !sel_srs,			///
			mcolor(blue*.5)				///
			msymbol(Oh)				///
		)						///
		(scatter y x if sel_srs,			///
			mcolor(red)				///
		)						///
		, `twopts'					///
		`ttl'						///
		name(srs)
graph export ../tex/pics/pic_srs.pdf, replace

local ttl title("Cluster sample `N_psu' (`M_psu' obs)")
graph twoway	(scatter y x if !sel_psu,			///
			mcolor(blue*.5)				///
			msymbol(Oh)				///
		)						///
		(scatter y x if sel_psu,			///
			mcolor(red)				///
		)						///
		, `twopts'					///
		yline(0/10, lcolor(gray))			///
		xline(0/10, lcolor(gray))			///
		`ttl'						///
		name(psu)
graph export ../tex/pics/pic_psu.pdf, replace

local ttl title("Stratified sample `N_str'")
graph twoway	(scatter y x if stratum==1 & !sel_str,		///
			mcolor(blue*.5)				///
			msymbol(Oh)				///
		)						///
		(scatter y x if stratum==2 & !sel_str,		///
			mcolor(blue*.5)				///
			msymbol(Th)				///
		)						///
		(scatter y x if stratum==3 & !sel_str,		///
			mcolor(blue*.5)				///
			msymbol(Sh)				///
		)						///
		(scatter y x if stratum==4 & !sel_str,		///
			mcolor(blue*.5)				///
			msymbol(Dh)				///
		)						///
		(scatter y x if stratum==1 & sel_str,		///
			mcolor(red)				///
		)						///
		(scatter y x if stratum==2 & sel_str,		///
			mcolor(red)				///
			msymbol(T)				///
		)						///
		(scatter y x if stratum==3 & sel_str,		///
			mcolor(red)				///
			msymbol(S)				///
		)						///
		(scatter y x if stratum==4 & sel_str,		///
			mcolor(red)				///
			msymbol(D)				///
		)						///
		, `twopts'					///
		yline(0 5 10, lcolor(black) lwidth(thick))	///
		xline(0 5 10, lcolor(black) lwidth(thick))	///
		`ttl'						///
		name(str)
graph export ../tex/pics/pic_str.pdf, replace

local ttl title("Stratified-cluster sample `N_scl' (`M_scl' obs)")
graph twoway	(scatter y x if stratum==1 & !sel_scl,		///
			mcolor(blue*.5)				///
			msymbol(Oh)				///
		)						///
		(scatter y x if stratum==2 & !sel_scl,		///
			mcolor(blue*.5)				///
			msymbol(Th)				///
		)						///
		(scatter y x if stratum==3 & !sel_scl,		///
			mcolor(blue*.5)				///
			msymbol(Sh)				///
		)						///
		(scatter y x if stratum==4 & !sel_scl,		///
			mcolor(blue*.5)				///
			msymbol(Dh)				///
		)						///
		(scatter y x if stratum==1 & sel_scl,		///
			mcolor(red)				///
		)						///
		(scatter y x if stratum==2 & sel_scl,		///
			mcolor(red)				///
			msymbol(T)				///
		)						///
		(scatter y x if stratum==3 & sel_scl,		///
			mcolor(red)				///
			msymbol(S)				///
		)						///
		(scatter y x if stratum==4 & sel_scl,		///
			mcolor(red)				///
			msymbol(D)				///
		)						///
		, `twopts'					///
		yline(0 5 10, lcolor(black) lwidth(thick))	///
		yline(1/4 6/9, lcolor(gray))			///
		xline(0 5 10, lcolor(black) lwidth(thick))	///
		xline(1/4 6/9, lcolor(gray))			///
		`ttl'						///
		name(scl)
graph export ../tex/pics/pic_scl.pdf, replace

* finished pics.do
